.. :changelog:

History
-------

0.2.0 (2017-01-17)
++++++++++++++++++

* Fixed method of rendering field so form would pull out the data
* Refactored how the project templates were structured and how to include the new template override
* Updated documentation

0.1.0 (2017-01-14)
++++++++++++++++++

* First release on PyPI.
